==> apache-paimon-0.8.1-src.tgz: paimon-0.8.1/paimon-flink/paimon-flink-common/src/main/java/org/apache/paimon/flink/sink/CompactionTaskTypeInfo.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.paimon.flink.sink;

import org.apache.paimon.append.AppendOnlyCompactionTask;
import org.apache.paimon.table.sink.CompactionTaskSerializer;

import org.apache.flink.api.common.ExecutionConfig;
import org.apache.flink.api.common.typeinfo.TypeInformation;
import org.apache.flink.api.common.typeutils.TypeSerializer;
import org.apache.flink.core.io.SimpleVersionedSerializerTypeSerializerProxy;

/** Type information of {@link AppendOnlyCompactionTask}. */
public class CompactionTaskTypeInfo extends TypeInformation<AppendOnlyCompactionTask> {

    @Override
    public boolean isBasicType() {
        return false;
    }

    @Override
    public boolean isTupleType() {
        return false;
    }

    @Override
    public int getArity() {
        return 1;
    }

    @Override
    public int getTotalFields() {
        return 1;
    }

    @Override
    public Class<AppendOnlyCompactionTask> getTypeClass() {
        return AppendOnlyCompactionTask.class;
    }

    @Override
    public boolean isKeyType() {
        return false;
    }

    @Override
    public TypeSerializer<AppendOnlyCompactionTask> createSerializer(ExecutionConfig config) {
        // we don't need copy for task
        return new SimpleVersionedSerializerTypeSerializerProxy<AppendOnlyCompactionTask>(
                () -> new CompactionTaskSimpleSerializer(new CompactionTaskSerializer())) {
            @Override
            public AppendOnlyCompactionTask copy(AppendOnlyCompactionTask from) {
                return from;
            }

            @Override
            public AppendOnlyCompactionTask copy(
                    AppendOnlyCompactionTask from, AppendOnlyCompactionTask reuse) {
                return from;
            }
        };
    }

    @Override
    public int hashCode() {
        return 0;
    }

    @Override
    public boolean canEqual(Object obj) {
        return obj instanceof CompactionTaskTypeInfo;
    }

    @Override
    public boolean equals(Object obj) {
        return obj instanceof CompactionTaskTypeInfo;
    }

    @Override
    public String toString() {
        return "CompactionTask";
    }
}

==> apache-paimon-0.9.0-src.tgz: paimon-0.9.0/paimon-flink/paimon-flink-common/src/main/java/org/apache/paimon/flink/sink/CompactionTaskTypeInfo.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.paimon.flink.sink;

import org.apache.paimon.append.UnawareAppendCompactionTask;
import org.apache.paimon.table.sink.CompactionTaskSerializer;

import org.apache.flink.api.common.ExecutionConfig;
import org.apache.flink.api.common.typeinfo.TypeInformation;
import org.apache.flink.api.common.typeutils.TypeSerializer;

/** Type information of {@link UnawareAppendCompactionTask}. */
public class CompactionTaskTypeInfo extends TypeInformation<UnawareAppendCompactionTask> {

    @Override
    public boolean isBasicType() {
        return false;
    }

    @Override
    public boolean isTupleType() {
        return false;
    }

    @Override
    public int getArity() {
        return 1;
    }

    @Override
    public int getTotalFields() {
        return 1;
    }

    @Override
    public Class<UnawareAppendCompactionTask> getTypeClass() {
        return UnawareAppendCompactionTask.class;
    }

    @Override
    public boolean isKeyType() {
        return false;
    }

    @Override
    public TypeSerializer<UnawareAppendCompactionTask> createSerializer(ExecutionConfig config) {
        // we don't need copy for task
        return new NoneCopyVersionedSerializerTypeSerializerProxy<UnawareAppendCompactionTask>(
                () -> new CompactionTaskSimpleSerializer(new CompactionTaskSerializer())) {};
    }

    @Override
    public int hashCode() {
        return 0;
    }

    @Override
    public boolean canEqual(Object obj) {
        return obj instanceof CompactionTaskTypeInfo;
    }

    @Override
    public boolean equals(Object obj) {
        return obj instanceof CompactionTaskTypeInfo;
    }

    @Override
    public String toString() {
        return "CompactionTask";
    }
}
